==> dasu_4.11.jar: edu/northwestern/dasu/measurement/types/AlternateType.java <==
/**
 * Dasu Project
 *
 * File:         ProbeType.java
 * RCS:          $Id$
 * Description:  ProbeType class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Oct 2, 2010 at 8:31:59 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.measurement.types;


/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The ProbeType class ...
 */

public enum AlternateType implements EventTypeInterface {
	RE_REQUEST(-1, -1),
	HALT(-1, -1);
	
	private int numProbesPerHour;
	private int numProbesPerMin;
	private String type;
	
	AlternateType(int probesPerHour, int probesPerMinute) {
		numProbesPerHour = probesPerHour;
		numProbesPerMin = probesPerMinute;
		this.type = this.name();
	}
	
	public int getMaxPerHour() {
		return numProbesPerHour;
	}
	
	public int getMaxPerMin() {
		return numProbesPerMin;
	}
	
	public String getType() {
		return type;
	}

	
}

==> dasu_5.31.jar: edu/northwestern/dasu/measurement/types/AlternateType.java <==
/**
 * Dasu Project
 *
 * File:         ProbeType.java
 * RCS:          $Id$
 * Description:  ProbeType class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Oct 2, 2010 at 8:31:59 PM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2010, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.measurement.types;


/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The ProbeType class ...
 */

public enum AlternateType implements EventType {
	RE_REQUEST(-1, -1, -1),
	AME_REQUEST(-1, -1, -1),
	HALT(-1, -1, -1);
	
	private int numProbesPerHour;
	private int numProbesPerMin;
	private int consumedBW; //units for now
	private String type;
	private boolean executeInIsolation = false;
	private boolean pauseOtherModules = false;
	
	private AlternateType(int probesPerMinute, int probesPerHour, int consumedBW) {		
		this.numProbesPerMin = probesPerMinute;
		this.numProbesPerHour = probesPerHour;
		this.consumedBW = consumedBW;
		this.type = this.name();
	}
	
	private AlternateType(int probesPerMinute, int probesPerHour, int consumedBW, boolean pauseOtherModules, boolean executeInIsolation) {
		this(probesPerMinute, probesPerHour, consumedBW);
		this.executeInIsolation = executeInIsolation;		
		this.pauseOtherModules = pauseOtherModules;
	}

	public int getMaxPerHour() {
		return numProbesPerHour;
	}
	
	public int getMaxPerMin() {
		return numProbesPerMin;
	}
	
	public String getEventType() {
		return type;
	}
	
	public int getConsumedBW() {
		return consumedBW;
	}
	
	public boolean isExecuteInIsolation() {
		return executeInIsolation;
	}

	public boolean isPauseOtherModules() {
		return pauseOtherModules;
	}
	
}
